"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../..");
const push_operation_1 = require("../operations/push.operation");
const delete_operation_1 = require("../operations/delete.operation");
class Datastore {
    constructor(name, type, adapter) {
        this.name = name;
        this.type = type;
        this.adapter = adapter;
    }
    get(condition) {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof condition === 'string') {
                return this.adapter.get(condition);
            }
            else {
                const keys = Object.keys(condition);
                return new __1.GetOperation(this).filter((item) => {
                    for (const key of keys) {
                        const passesKey = item[key] === condition[key];
                        if (!passesKey) {
                            return false;
                        }
                    }
                    return true;
                }).one();
            }
        });
    }
    getItems(filter, pagination) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = new __1.GetOperation(this);
            if (filter) {
                query.filter(filter);
            }
            if (pagination) {
                query.paginate(pagination);
            }
            return query.run();
        });
    }
    push(item) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = new __1.PushOperation(this);
            return query.item(item).run();
        });
    }
    pushItems(items) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = new push_operation_1.BatchedPushOperation(this);
            return query.items(items).run();
        });
    }
    remove(item) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = new __1.DeleteOperation(this);
            return query.value(item).run();
        });
    }
    removeItems(items) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = new delete_operation_1.BatchedDeleteOperation(this);
            return query.values(items).run();
        });
    }
}
exports.Datastore = Datastore;
//# sourceMappingURL=datastore.js.map